@@ -82,6 +82,10 @@ func (b *Browser) Init(ctx context.Context) error {
 	return nil
 }
 
+func (b *Browser) InCmdMode() bool {
+	return b.CmdBuff().InCmdMode()
+}
+
 func (b *Browser) suggestFilter() model.SuggestionFunc {
 	return func(s string) (entries sort.StringSlice) {
 		if s == "" {
@@ -108,6 +112,7 @@ func (b *Browser) bindKeys(aa ui.KeyActions) {
 	aa.Add(ui.KeyActions{
 		tcell.KeyEscape: ui.NewSharedKeyAction("Filter Reset", b.resetCmd, false),
 		tcell.KeyEnter:  ui.NewSharedKeyAction("Filter", b.filterCmd, false),
+		tcell.KeyHelp:   ui.NewSharedKeyAction("Help", b.helpCmd, false),
 	})
 }
 
@@ -241,6 +246,14 @@ func (b *Browser) viewCmd(evt *tcell.EventKey) *tcell.EventKey {
 	return nil
 }
 
+func (b *Browser) helpCmd(evt *tcell.EventKey) *tcell.EventKey {
+	if b.CmdBuff().InCmdMode() {
+		return nil
+	}
+
+	return evt
+}
+
 func (b *Browser) resetCmd(evt *tcell.EventKey) *tcell.EventKey {
 	if !b.CmdBuff().InCmdMode() {
 		b.CmdBuff().ClearText(false)
