@@ -260,6 +260,9 @@ func (c *Command) exec(cmd, gvr string, comp model.Component, clearStack bool) (
 		return fmt.Errorf("No component found for %s", gvr)
 	}
 	c.app.Flash().Infof("Viewing %s...", client.NewGVR(gvr).R())
+	if tokens:= strings.Split(cmd, " "); len(tokens) >= 2 {
+		cmd = tokens[0]
+	}
 	c.app.Config.SetActiveView(cmd)
 	if err := c.app.Config.Save(); err != nil {
 		log.Error().Err(err).Msg("Config save failed!")
