@@ -34,10 +34,10 @@ type Pod struct {
 
 // NewPod returns a new viewer.
 func NewPod(gvr client.GVR) ResourceViewer {
-	p := Pod{}
+	var p Pod
 	p.ResourceViewer = NewPortForwardExtender(
 		NewImageExtender(
-			NewLogsExtender(NewBrowser(gvr), p.selectedContainer),
+			NewLogsExtender(NewBrowser(gvr), p.logOptions),
 		),
 	)
 	p.AddBindKeysFn(p.bindKeys)
@@ -85,21 +85,37 @@ func (p *Pod) bindKeys(aa ui.KeyActions) {
 	aa.Add(resourceSorters(p.GetTable()))
 }
 
-func (p *Pod) selectedContainer() string {
+func (p *Pod) logOptions() (*dao.LogOptions, error) {
 	path := p.GetTable().GetSelectedItem()
 	if path == "" {
-		return ""
+		return nil, errors.New("you must provide a selection")
 	}
 
-	cc, err := fetchContainers(p.App().factory, path, true)
+	pod, err := fetchPod(p.App().factory, path)
 	if err != nil {
-		log.Error().Err(err).Msgf("Fetch containers")
-		return ""
+		return nil, err
 	}
-	if len(cc) == 1 {
-		return cc[0]
+
+	cc := fetchContainers(pod.Spec, true)
+
+	cfg := p.App().Config.K9s.Logger
+	opts := dao.LogOptions{
+		Path:            path,
+		Lines:           int64(cfg.TailCount),
+		SinceSeconds:    cfg.SinceSeconds,
+		SingleContainer: len(cc) == 1,
+		AllContainers:   false,
+		ShowTimestamp:   cfg.ShowTime,
 	}
-	return ""
+	if c, ok := dao.GetDefaultLogContainer(pod.ObjectMeta, pod.Spec); ok {
+		opts.Container, opts.DefaultContainer = c, c
+	} else if len(cc) == 1 {
+		opts.Container = cc[0]
+	} else {
+		opts.AllContainers = true
+	}
+
+	return &opts, nil
 }
 
 func (p *Pod) showContainers(app *App, model ui.Tabular, gvr, path string) {
@@ -221,10 +237,11 @@ func containerShellin(a *App, comp model.Component, path, co string) error {
 		return nil
 	}
 
-	cc, err := fetchContainers(a.factory, path, false)
+	pod, err := fetchPod(a.factory, path)
 	if err != nil {
 		return err
 	}
+	cc := fetchContainers(pod.Spec, false)
 	if len(cc) == 1 {
 		resumeShellIn(a, comp, path, cc[0])
 		return nil
@@ -234,11 +251,8 @@ func containerShellin(a *App, comp model.Component, path, co string) error {
 	picker.SetSelectedFunc(func(_ int, co, _ string, _ rune) {
 		resumeShellIn(a, comp, path, co)
 	})
-	if err := a.inject(picker); err != nil {
-		return err
-	}
 
-	return nil
+	return a.inject(picker)
 }
 
 func resumeShellIn(a *App, c model.Component, path, co string) {
@@ -267,10 +281,11 @@ func containerAttachIn(a *App, comp model.Component, path, co string) error {
 		return nil
 	}
 
-	cc, err := fetchContainers(a.factory, path, false)
+	pod, err := fetchPod(a.factory, path)
 	if err != nil {
 		return err
 	}
+	cc := fetchContainers(pod.Spec, false)
 	if len(cc) == 1 {
 		resumeAttachIn(a, comp, path, cc[0])
 		return nil
@@ -328,24 +343,22 @@ func buildShellArgs(cmd, path, co string, kcfg *string) []string {
 	return args
 }
 
-func fetchContainers(f dao.Factory, path string, includeInit bool) ([]string, error) {
-	pod, err := fetchPod(f, path)
-	if err != nil {
-		return nil, err
-	}
-
-	nn := make([]string, 0, len(pod.Spec.Containers)+len(pod.Spec.InitContainers))
-	for _, c := range pod.Spec.Containers {
+func fetchContainers(spec v1.PodSpec, allContainers bool) []string {
+	nn := make([]string, 0, len(spec.Containers)+len(spec.InitContainers))
+	for _, c := range spec.Containers {
 		nn = append(nn, c.Name)
 	}
-	if !includeInit {
-		return nn, nil
+	if !allContainers {
+		return nn
 	}
-	for _, c := range pod.Spec.InitContainers {
+	for _, c := range spec.InitContainers {
+		nn = append(nn, c.Name)
+	}
+	for _, c := range spec.EphemeralContainers {
 		nn = append(nn, c.Name)
 	}
 
-	return nn, nil
+	return nn
 }
 
 func fetchPod(f dao.Factory, path string) (*v1.Pod, error) {
